#!/bin/sh

###########################################################################
#
# SCRIPT to convert and generate the TIGCC Tools Suite on Linux Systems
#
# v 0.2 (tested on Suse 6.x and Suse 7.x)
#
###########################################################################
#
# This script generates a directory called linuxsrc and linuxbin.
# Unix file versions of all files in the normal src directory tree are
# generated in directory linuxsrc.
# Afterwards the pctools are build and the executables are stored in
# directory linuxbin.
#
# To use the TIGCC Tools Suite please add the linuxbin directory to
# your PATH.
#
# Due to the fact that the commandline parameter style of command
# recode is incompatible between Linux 6.x and 7.x installations 
# recode cannot be used to convert DOS files to UNIX files.
# Instead of recode a dirty "cat -vte" in combination with
# 2 sed filters is used which IS compatible between Linux 6.x and
# 7.x
#
# I cannot understand why programmers are that stupid to change
# the main commandline parameter style of a tool like recode.
# This way the tool disqualify itself for compatible scripts.
#
###########################################################################
directories=`ls src`

echo ====== generating linuxbin directory ============
if test -e linuxbin ; then
   echo directory linuxbin does already exists
else
   echo generating directory linuxbin
   mkdir linuxbin
fi

echo ====== generating linuxsrc directory tree =======
if test -e linuxsrc ; then
   echo directory linuxsrc does already exists
else
   echo generating directory linuxsrc
   mkdir linuxsrc
fi

for i in $directories
do
   if test -d src/$i ; then
      if test -e linuxsrc/$i ; then
          echo directory linuxsrc/$i does already exists
      else
          echo generating directory linuxsrc/$i
          mkdir linuxsrc/$i          
      fi
   fi
done

echo ====== converting source files ==================

for i in $directories
do
    if test -d src/$i ; then
        echo ------ processing directory src/$i -------
        cd src/$i
        allfiles=`ls *.c *.h 2>/dev/null`

        for j in $allfiles 
        do 
            echo converting src/$i/$j ...
            #cat $j | recode ibmpc..lat1 > ../../linuxsrc/$i/$j
            cat -vte $j | sed 's/\^M\$//g' | sed 's/\^I/	/g' > ../../linuxsrc/$i/$j
        done

        cd ../..

    fi
done

echo ====== generating linux binaries ==================
cd linuxsrc/pctools
allfiles=`ls tt*.c`
for j in $allfiles 
do 
    echo building $j ...
    outname=`echo $j | cut -f1 -d.`
    gcc -o ../../linuxbin/$outname $j
done
cd ../..

